@@ -3,6 +3,7 @@ Factual API driver
 """
 
 import json
+from functools import partial
 from urllib import urlencode
 
 import requests
@@ -11,7 +12,7 @@ from requests_oauthlib import OAuth1
 from query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi, Clear
 
 API_V3_HOST = "http://api.v3.factual.com"
-DRIVER_VERSION_TAG = "factual-python-driver-1.4.0"
+DRIVER_VERSION_TAG = "factual-python-driver-1.4.1"
 
 class Factual(object):
     def __init__(self, key, secret, timeout=None):
@@ -20,18 +21,17 @@ class Factual(object):
         self.timeout = timeout
         self.api = API(self._generate_token(key, secret),timeout)
 
-
     def table(self, table):
         return Table(self.api, 't/' + table)
 
     def crosswalk(self):
         return Table(self.api, 't/crosswalk')
 
-    def resolve(self, values):
-        return Resolve(self.api, {'values': values})
+    def resolve(self, table, values):
+        return Resolve(self.api, table, {'values': values})
 
-    def match(self, values):
-        return Match(self.api, {'values': values})
+    def match(self, table, values):
+        return Match(self.api, table, {'values': values})
 
     def raw_read(self, path, raw_params):
         return self.api.raw_read(path, raw_params)
@@ -69,6 +69,10 @@ class Factual(object):
     def multi(self, queries):
         return Multi(self.api, queries).make_request()
 
+    def get_row(self, table, factual_id):
+        data = self.table(table).factual_id(factual_id).data()
+        return data[0]
+
     def _generate_token(self, key, secret):
         access_token = OAuth1(key, secret)
         return access_token
@@ -98,7 +102,7 @@ class API(object):
 
     def raw_stream_read(self, path, raw_params):
         url = self._build_base_url(path)
-        for line in self._make_request(url, raw_params, self._make_get_request).iter_lines():
+        for line in self._make_request(url, raw_params, partial(self._make_get_request, stream=True)).iter_lines():
             if line:
                 yield line
 
@@ -132,9 +136,9 @@ class API(object):
             raise APIException(response.status_code, response.text, response.url)
         return response
 
-    def _make_get_request(self, url, params):
+    def _make_get_request(self, url, params, stream=False):
         headers = {'X-Factual-Lib': DRIVER_VERSION_TAG}
-        return self.client.get(url, headers=headers, params=params, timeout=self.client.timeout)
+        return self.client.get(url, headers=headers, params=params, timeout=self.client.timeout, stream=stream)
 
     def _make_post_request(self, url, params):
         headers = {'X-Factual-Lib': DRIVER_VERSION_TAG, 'content-type': 'application/x-www-form-urlencoded'}
